
****************************** INDATA.DO *****************************
* This file prepares the individual file for Rwanda
* Syntax:
* do indata.do  `1' 
* where 	`1': root where results are stored
*		
* EB, March 2005
***********************************************************************

/*

This file uses:
	"C:\Documents and Settings\wb200856\My Documents\Africa\rwa\indiv_data.dta

This file creates:
	"C:\Documents and Settings\wb200856\My Documents\Africa\rwa\indata.dta

*/

version 8.0

clear
set memory 60m
set more off


cap log close

log using "C:\Documents and Settings\wb200856\My Documents\Africa\rwa\log_files\QUIBBindata.log", replace


use "C:\Documents and Settings\wb200856\My Documents\Africa\rwa\data\QUIBB\indiv_data.dta", clear
    
for var a1-a2: destring X , replace ignore ("?" "..")
gen double hhid= a1*1000 + a2

for var b1-b4: destring X , replace ignore ("?" "..")

for var b6-prov seg1 seg hgender: destring X , replace ignore ("?" "..")

compress


*** DEMOGRAPHIC VARIABLES

rename memnumbe memnum
sort hhid

label var memnum "individual identifier in the household"
label var hhid "household id"

ren b1 sex
recode sex 2=1 1=0
label def sex 0 "male" 1 "female"
label val sex sex
label var sex "sex (b1)"

ren b5 age
label var age "age (b5)"

ren b2 outhh
label var outhh "time spent outside the HH in previous 12 months (b2)"
label def outhh 1 "zero" 2 "<6 months" 3 ">6 months"
label val outhh outhh

ren b3 contrib
recode contrib 2=0
label var contrib "member contributes to HH income (b3)"

ren b4 relhead
label var relhead "relationship with household head (b4)"
label def relhead 1 "head" 2 "spouse" 3 "son/daughter" 4 "father/mother" 5 "other rel" /*
	*/ 6 "not related"
label var relhead relhead

ren b6 mastat
label var mastat "marital status (b6)"
label def mastat 1 "single" 2 "monog" 3 "polig" 4 "div/separ" 5 "widow/er"
label val mastat mastat

ren b7 fathalive
label var fathalive "father is alive (b7)"
label def paralive 1 "yes, in HH" 2 "yes, outside HH" 3 "no" 4 "do not know"
label val fathalive paralive

ren b8 mothalive
label var mothalive "mother is alive (b8)"
label val mothalive paralive



*** EDUCATION VARIABLES
ren c3 educmax
ren c6 educcur

label var educmax "highest level of education (c3)"
label var educcur "current school attended (c6)"

label def educ 0 "none" 1 "pre-school" 11 "P1" 12 "P2" 13 "P3" 14 "P4" 15 "P5" /*
	*/ 16 "P6" 21 "S1" 22 "S2" 23 "S3" 24 "S4" 25 "S5" 26 "S6" 31 "University" /*
	*/ 41 "prof education" 42 "tech education" 43 "less than 6"
label val educcur educ
label val educmax educ
replace educmax=43 if age<6
replace educcur=43 if age<6

ren c1 literate
recode literate 2=0
label var literate "literate (c1)"

ren c2 attschool
recode attschool 2=0
label var attschool "ever attended school (c2)"

ren c4 schly
recode schly 2=0
label var schly "attended school last year (c4)"

ren c5 schnow
recode schnow 2=0
label var schnow "currently in school (c5)"

ren c7 typesch
label var typesch "type of school currently attended (c7)"

ren c8a snoprob
recode snoprob 2=0
label var snoprob "no problems with school (c8a): 1=no prob 0=some pr"

ren c8b snobooks
recode snobooks 2=0
label var snobooks "no books/equipment at school (c8b)"

ren c8c sbadteach
recode sbadteach 2=0
label var sbadteach "bad teaching quality (c8c)"

ren c8d snoprof
recode snoprof 2=0
label var snoprof "lack of professors (c8d)"

ren c8e sbadcond
recode sbadcond 2=0
label var sbadcond "school in bad conditions (c8e)"

ren c8f sothprob
recode sothprob 2=0
label var sothprob "school has other problems (c8f)"

ren c9a nsended
recode nsended 2=0
label var nsended "not currently in school: ended (c9a)"

ren c9b nsfar
recode nsfar 2=0
label var nsfar "not currently in school: too far (c9b)"

ren c9c nsexp
recode nsexp 2=0
label var nsexp "not currently in school: too expensive (c9c)"

ren c9d nswork
recode nswork 2=0
label var nswork "not currently in school: work (c9d)"

ren c9e nsnoint
recode nsnoint 2=0
label var nsnoint "not currently in school: no interest (c9e)"

ren c9f nspregn
recode nspregn 2=0
label var nspregn "not currently in school: pregnant/sick (c9f)"

ren c9g nsfailed
recode nsfailed 2=0
label var nsfailed "not currently in school: failed (c9g)"

ren c9h nsmarried
recode nsmarried 2=0
label var nsmarried "not currently in school: got married (c9h)"

ren c9i nsother
recode nsother 2=0
label var nsother "not currently in school: other reason (c9i)"


label def typesch 1 "govern" 2 "church" 3 "private" 4 "community" 5 "other"
label val typesch typesch



*** HEALTH VARIABLES

ren d1 livebirth
label var livebirth "had live birth in the last 12 months (d1)"
recode livebirth 2=0

ren d2 prenat
label var prenat "received pre-natal care (d2)"
recode prenat 2=0

ren d3 disabled
label var disabled "permanent disability (d3)"
* recode disabled 2=0

ren d4 sick
label var sick "sick or injured in the past 4 weeks (d4)"
recode sick 2=0

ren d5a malaria
label var malaria "has malaria/fever (d5a)"
recode malaria 2=0

ren d5b diarrhea
label var diarrhea "has diarrhea (d5b)"
recode diarrhea 2=0

ren d5c accident
label var accident "had accident (d5c)"
recode accident 2=0

ren d5d teeth
label var teeth "teeth problem (d5d)"
recode teeth 2=0

ren d5e skin
label var skin "skin problem (d5e)"
recode skin 2=0

ren d5f eye
label var eye "eye problem (d5f)"
recode eye 2=0

ren d5g ear
label var ear "ear/nose/throat problem (d5g)"
recode ear 2=0

ren d5h othsick
label var othsick "other medical problem (d5h)"
recode othsick 2=0

ren d6 dayslost
label var dayslost "days out of work last 4 weeks because of sickness (d6)"
label def dayslost 1 "none" 2 "less than 1 week" 3 "1 to 2 weeks" 4 "2 weeks+"
label val dayslost dayslost

tab dayslost sick, miss

ren d7 doctor
label var doctor "visited doctor in the last 4 weeks (d7)"
recode doctor 2=0

ren d8 typedoct
replace typedoct=0 if doctor==0
label var typedoct "type of doctor visited in the last 4 weeks (d8)"
label def typedoct 0 "none" 1 "public hospital" 2 "church hospital" 3 "public health center" /*
	*/ 4 "private doctor/dentist" 5 "traditional doctor" 6 "pharmacy" 7 "other"
label val typedoct typedoct

ren d9 nrvisit
label var nrvisit "number of visits to the doctor in last 4 weeks (d9)"
label def nrvisit 1 "1-3 times" 2 "4-6 times" 3 ">6 times"
label val nrvisit nrvisit


ren d10a medprob
label var medprob "problems vis-a-vis doctor consultation (d10a): 1=some prob 0=no pr"
recode medprob 2=1 1=0

ren d10b dbadrec
label var dbadrec "doctor: bad reception (d10b)"
recode dbadrec 2=0

ren d10c dlongwait
label var dlongwait "doctor: long waiting time (d10c)"
recode dlongwait 2=0

ren d10d dnoperson
label var dnoperson "doctor: no qualified personnel (d10d)"
recode dnoperson 2=0

ren d10e dexpens
label var dexpens "doctor: expensive (d10e)"
recode dexpens 2=0

ren d10f dnodrug
label var dnodrug "doctor: no medicines (d10f)"
recode dnodrug 2=0

ren d10g dnoresult
label var dnoresult "doctor: no results obtained (d10g)"
recode dnoresult 2=0

ren d10h dother
label var dother "doctor: other problems (d10h)"
recode dother 2=0

ren d11a dnoneed
label var dnoneed "no doctor: not necessary (d11a)"
recode dnoneed 2=0

ren d11b dnoexp
label var dnoexp "no doctor: too expensive (d11b)"
recode dnoexp 2=0

ren d11c dnofar
label var dnofar "no doctor: too far (d11c)"
recode dnofar 2=0

ren d11d dnother
label var dnother "no doctor: other reasons (d11d)"
recode dnother 2=0



*** EMPLOYMENT VARIABLES

ren e1 jbhas
recode jbhas 2=0
label var jbhas "has worked in past 7 days (e1)"

ren e2 jboff
recode jboff 2=0
label var jboff "has job, but was absent in past 7 days (e2)"

ren e3 jbavail
recode jbavail 2=0
label var jbavail "was available to work in past 4 weeks (e3)"

ren e4 whyout
label var whyout "reason why not in work in past 7 days (e4)"

ren e5 nrjobs
label var nrjobs "number of jobs in past 7 days (e5)"

ren e6 howpaid
label var howpaid "how was paid in main job (e6)"

ren e7 employer
label var employer "type of employer (e7)"

ren e8 industry
label var industry "industry of main job (e8)"

ren e9 improve
label var improve "attempts to increase earnings in past 7 days (e9)"
recode improve 2=0


ren e10 wayimpr
label var wayimpr "strategy adopted to increase earnings (e10)"

ren e11 extrajob
label var extrajob "available to take more work in next 4 weeks (e11)"
recode extrajob 2=0


label define yesno 0 "no" 1 "yes"
label val jbhas yesno
label val jboff yesno
label val jbavail yesno
label val snoprob yesno
label val snobooks yesno
label val snoprof yesno
label val sbadcond yesno
label val sothprob yesno
label val sbadteach yesno


label def whyout 1 "no job" 2 "seas inact" 3 "studies" 4 "family reasons" 5 "too young/old" /*
	*/ 6 "disabled" 7 "other"
label val whyout whyout

label def nrjobs 1 "1 job" 2 "2 jobs" 3 ">2 jobs"
label val nrjobs nrjobs

label def howpaid 1 "wage (cash/kind)" 2 "casual (/hr,/day)" 3 "family aid" 4 "self-empl"
label val howpaid howpaid

label def employer 1 "government" 2 "other public" 3 "private" 4 "self-empl/fam enter" 
label val employer employer

label def industry 0 "agric" 1 "mines" 2 "manuf" 3 "constr" 4 "transp" 5 "trade" /*
	*/ 6 "service" 7 "educ/health" 8 "publ admin" 9 "other"
label val industry industry

*~*~*~*

ren orph_p orphf
ren orph_m orphm
lab var orphf "orphan of father"
lab var orphm "orphan of mother"
ren orphelin orphan 
label var orphan "orphan of at least one parent"
ren orph_pm orphfm
label var orphfm "orphan of both parents"

ren clage cohort
ren clage5 cohort5
label var cohort "birth cohort"
label var cohort5 "birth cohort (5 years)"

label drop clage
label drop clage5

label define cohort 1 "<15" 2 "15-64" 3 "65+"
label define cohort5 1 "<5" 2 "5-9" 3 "10-14" 4 "15-19" 5 "20-24" 6 "25-29" 7 "30-34" /*
	*/ 8 "35-39" 9 "40-44" 10 "45-49" 11 "50-54" 12 "55-59" 13 "60-64" 14 "65-69" /*
	*/ 15 "70-74" 16 "75-79" 17 "80+"
label val cohort cohort 
label val cohort5 cohort5


label var hhsize "number of people in the household"
ren autpond hhweight
label var hhweight "household weight"

drop alphab

order hhid a1 a2 strate prov seg seg1 memnum hhweight hhsize sex age cohort* relhead fathalive /*
	*/ mothalive orphf orphm orphan orphfm mastat outhh contrib literate-schnow /*
	*/ educmax educcur typesch-extrajob 



save "C:\Documents and Settings\wb200856\My Documents\Africa\rwa\data\QUIBB\indata.dta", replace

log close

***********************************************************************
