
****************************** SECTIONH.DO *******************************
* This file prepares the data of section H of the questionnaire for Rwanda
* Syntax:
* do sectionh.do  `1' `2'
* where 	`1': root where data are stored
*		`2': root where programs and log are stored
*
* EB, March 2005
**************************************************************************

version 8.0

clear
set memory 60m
set more off


cap log close

log using "C:\Documents and Settings\wb200856\My Documents\Africa\rwa\data\QUIBB\sectionh.log", replace

use "C:\Documents and Settings\wb200856\My Documents\Africa\rwa\data\QUIBB\sectionh_2.dta", clear

for var refno-seg1: destring X , replace ignore ("?" ".." ".N" "N")

gen double hhid= a1*1000 + a2

compress


*** TYPE OF HABITAT (H1)

ren h11 habitat
label def habitat 1 "isolated" 2 "historical" 3 "imidugudu" 4 "temporary" 5 "cadastral lot"
label val habitat habitat
label var habitat "type of habitat"

ren h12 area
label def area 1 "flood area" 2 "hill side" 3 "normal area"
label val area area
label var area "type of area where house is"

ren h13 migr2
label def migr2 1 "same quarter" 2 "same district" 3 "same province" 4 "other province urban" /*
	*/ 5 "other province rural" 6 "abroad" 
label val migr2 migr2
replace migr2=. if migr2==7
label var migr2 "area of residence 2 years ago"

ren h14a theftcash
label var theftcash "cash was stolen over the past 12 months"
replace theftcash=0 if theftcash==.

ren h14b theftgoods
label var theftgoods "goods were stolen over the past 12 months"
replace theftgoods=0 if theftgoods==.

ren h14c violence
label var violence "HH suffered from violence over the past 12 months"
replace violence=0 if violence==.

ren h14d fire
label var fire "HH suffered from fire over the past 12 months"
replace fire=0 if fire==.

ren h14e flood
label var flood "HH suffered from flood over the past 12 months"
replace flood=0 if flood==.

ren h14f landslide
label var landslide "HH suffered from landslide over the past 12 months"
replace landslide=0 if landslide==.

ren h14g disrepair
label var disrepair "HH suffered from house disrepair over the past 12 months"
replace disrepair=0 if disrepair==.

ren h14h noprob
label var noprob "HH did not have any special damage in past 12 months"
replace noprob=0 if noprob==.


*** COMMUNITY LIFE

foreach var of varlist h21a-h21g {
replace `var'=0 if `var'==.
}

ren h21a memrel
label var memrel "member of a religious community"

ren h21b memprof
label var memprof "member of a professional community"

ren h21c memngo
label var memngo "member of a NGO"

ren h21d memparent
label var memparent "member of pupil parents' association"

ren h21e memgender
label var memgender "member of a man or women association"

ren h21f memelite
label var memelite "member of an elite/native group"

ren h21g memnone
label var memnone "NOT a member of any association"

 
foreach var of varlist h22a-h22g {
replace `var'=0 if `var'==.
}

ren h22a infotv
label var infotv "source of news: TV"

ren h22b inforadio
label var inforadio "source of news: radio"

ren h22c infonewsp
label var infonewsp "source of news: newspaper"

ren h22d infochat
label var infochat "source of news: talks with neighbors"

ren h22e infomeet
label var infomeet "source of news: meetings"

ren h22f infonoacc
label var infonoacc "source of news: no access"

ren h22g infonoint
label var infonoint "source of news: no interest"


foreach var of varlist h23a-h23e {
replace `var'=0 if `var'==2
}

ren h23a knpoverty
label var knpoverty "HH knows about poverty reduction strategies"

ren h23b kndecentr
label var kndecentr "HH knows about decentralization policies"

ren h23c kntaxes
label var kntaxes "HH knows about abolishing flat tax"

ren h23d kntaxan
label var kntaxan "HH knows about abolishing flat tax on cows"

ren h23e knseeds
label var knseeds "HH knows about promotion of seeds and fertilizers"


ren h24 umuganda
label var umuganda "HH participated in Umuganda in past 2 years"

ren h25 umujudge
label var umujudge "how HH judges Umuganda realizations in the community"
label def umujudge 1 "very satisf" 2 "satisf" 3 "not satisf" 4 "no opinion"
recode umujudge 5=.
label val umujudge umujudge

ren h26 umufuture
label var umufuture "HH thinks Umuganda action needed in the future"
recode umufuture 2=0



*** HEALTH AND HYGIENE
ren h31 waterdrink
label var waterdrink "HH thinks water they drink is drinkable" 

ren h32 waterprec
label var waterprec "precautions adopted to drink bad quality water"
label def waterprec 1 "none" 2 "settling" 3 "boil" 4 "filter" 5 "disinfect" 
label val waterprec waterprec

ren h33 waterpres
label var waterpres "equipment used to preserve water"
label def waterpres 1 "shaft" 2 "tank" 3 "jug" 4 "other" 5 "not needed" 6 "none" 
label val waterpres waterpres

ren h34 waterbath
label var waterbath "HH has enough water for everybody to take a bath/day"
recode waterbath 2=0

ren h35 toothbrush
label var toothbrush "each HH member has a toothbrush"
recode toothbrush 2=0

ren h36 shoes
label var shoes "each HH member has at least one pair of shoes"
recode shoes 2=0

ren h37 healthins
label var healthins "at least one member has health insurance"
recode healthins 2=0

ren h38 illness
label var illness "at least one member suffers from long-term illness"
recode illness 2=0

ren h39 healthvisit
label var healthvisit "HH received one or more visits from a health officer in past year"
recode healthvisit 2=0



*** ENERGY FOR COOKING
ren h41 woodeasy
label var woodeasy "easy to get wood for cooking"
label def woodeasy 1 "yes - buy" 2 "yes - collect" 3 "yes - coal" 4 "no"
label val woodeasy woodeasy

ren h42 forest5
label var forest5 "opinion about forest situation in the community in 5 years"
label def forest5 1 "smaller" 2 "same" 3 "bigger" 4 "do not know" 
label val forest5 forest5
recode forest5 5=.

ren h43 meals
label var meals "number of meals consumed each day by members"

ren h44 meatfreq
label var meatfreq "how often meat/fish is consumed"
label def meatfreq 1 "seldom" 2 "<2 times/15 days" 3 "1 time/week" 4 "2+ times/week" 
label val meatfreq meatfreq

ren h45 kidbreak
label var kidbreak "children in the HH eat in the morning before school"
label def kidbreak 1 "yes, every day" 2 "yes, when possible" 3 "seldom" 4 "no"
label val kidbreak kidbreak

ren h46 kidlunch
label var kidlunch "children receive food to eat for lunch"
label def kidlunch 1 "not needed" 2 "one portion" 3 "some cash" 4 "no, no resources"
label val kidlunch kidlunch


*** LAND OWNERSHIP AND AGRICULTURAL ACTIVITIES

ren h51 agract
label var agract "at least one member has worked in a field in the past 12 months"
recode agract 2=0

ren h52 nfield
label var nfield "number of fields owned by the HH"

ren h53 fieldloc
label var fieldloc "location of fields"
label def fieldloc 1 "marsh" 2 "plain" 3 "mountain" 
label val fieldloc fieldloc

ren h54 surfevol
label var surfevol "evolution of field surface"
label def surfevol 1 "smaller" 2 "same" 3 "bigger" 4 "do not know" 5 "n/a"
label val surfevol surfevol

ren h55 landnown
label var landnown "HH works in fields that are not owned"
label def landnown 1 "no" 2 "rents" 3 "matayage" 4 "free private land" 5 "free access land"
label val landnown landnown

ren h56 nownfield
label var nownfield "number of non-owned fields used by the HH"
replace nownfield=. if nownfield==99

ren h57 nownsurf
label var nownsurf "evolution of surface of non-owned fields"
label val nownsurf surfevol


#delimit ;

label def crop
	1 "banana - cook"
	2 "banana - beer"
	3 "banana - fruit"
	4 "corn"
	5 "sorghum"
	6 "rice"
	7 "wheat"
	8 "beans"
	9 "peas"
	10 "peanut"
	11 "soia"
	12 "potato"
	13 "manioc"
	14 "taro (malanga)"
	15 "sweet potato"
	16 "onions"
	17 "cabbage"
	18 "dodo/lenga lenga"
	19 "tomato"
	20 "carrot"
	21 "salad"
	22 "other veget"
	23 "mushrooms"
	24 "maracuja"
	25 "pineapple"
	26 "flowers"
	27 "tobacco";

label def seed
	1 "traditional"
	2 "improved - local"
	3 "improved - import";

label def fertilizer
	1 "compost"
	2 "chemical";

label def usecrop
	1 "sale"
	2 "transformation"
	3 "consumption";

#delimit cr

ren h59a crop1
label var crop1 "1st main crop"
label val crop1 crop

ren h510a seeds1
label var seeds1 "1st crop: type of seeds"
label val seeds1 seed

ren h511a fertilizer1
label var fertilizer1 "1st crop: type of fertilizer"
label val fertilizer1 fertilizer

ren h512a usecrop1
label var usecrop1 "1st crop: use"
label val usecrop1 usecrop

ren h59b crop2
label var crop2 "2nd main crop"
label val crop2 crop

ren h510b seeds2
label var seeds2 "2nd crop: type of seeds"
label val seeds2 seed

ren h511b fertilizer2
label var fertilizer2 "2nd crop: type of fertilizer"
label val fertilizer2 fertilizer

ren h512b usecrop2
label var usecrop2 "2nd crop: use"
label val usecrop2 usecrop

ren h59c crop3
label var crop3 "3rd main crop"
label val crop3 crop

ren h510c seeds3
label var seeds3 "3rd crop: type of seeds"
label val seeds3 seed

ren h511c fertilizer3
label var fertilizer3 "3rd crop: type of fertilizer"
label val fertilizer3 fertilizer

ren h512c usecrop3
label var usecrop3 "3rd crop: use"
label val usecrop3 usecrop

ren h59d crop4
label var crop4 "4th main crop"
label val crop4 crop

ren h510d seeds4
label var seeds4 "4th crop: type of seeds"
label val seeds4 seed

ren h511d fertilizer4
label var fertilizer4 "4th crop: type of fertilizer"
label val fertilizer4 fertilizer

ren h512d usecrop4
label var usecrop4 "4th crop: use"
label val usecrop4 usecrop

ren h59e crop5
label var crop5 "5th main crop"
label val crop5 crop

ren h510e seeds5
label var seeds5 "5th crop: type of seeds"
label val seeds5 seed

ren h511e fertilizer5
label var fertilizer5 "5th crop: type of fertilizer"
label val fertilizer5 fertilizer

ren h512e usecrop5
label var usecrop5 "5th crop: use"
label val usecrop5 usecrop


foreach var of varlist crop1 crop2 crop3 crop4 crop5 {
replace `var'=. if `var'==99
}


ren h513 agrpart
label var agrpart "HH participated in agric meetings (past 12 months)"
recode agrpart 2=0

ren h514 prodsuff
label var prodsuff "last season agric production was enough to feed HH"
recode prodsuff 2=0



ren h515a strwage
label var strwage "use wage/income/savings when no resources"
replace strwage=. if strwage!=1
replace strwage=0 if prodsuff==0 & strwage!=1

ren h515b strwkind
label var strwkind "work for food when no resources"
replace strwkind=. if strwkind!=1
replace strwkind=0 if prodsuff==0 & strwkind!=1

ren h515c strsellasset
label var strsellasset "sell assets when no resources"
replace strsellasset=. if strsellasset!=1
replace strsellasset=0 if prodsuff==0 & strsellasset!=1

ren h515d strsellanim
label var strsellanim "sell animals when no resources"
replace strsellanim=. if strsellanim!=1
replace strsellanim=0 if prodsuff==0 & strsellanim!=1

ren h515e strlessmeal
label var strlessmeal "reduce number of meals when no resources"
replace strlessmeal=. if strlessmeal!=1
replace strlessmeal=0 if prodsuff==0 & strlessmeal!=1

ren h515f stralaid
label var stralaid "use food aid when no resources"
replace stralaid=. if stralaid!=1
replace stralaid=0 if prodsuff==0 & stralaid!=1

ren h515g strrelaid
label var strrelaid "use aid from relatives when no resources"
replace strrelaid=. if strrelaid!=1
replace strrelaid=0 if prodsuff==0 & strrelaid!=1

ren h515h stralgift
label var stralgift "use food gifts when no resources"
replace stralgift=. if stralgift!=1
replace stralgift=0 if prodsuff==0 & stralgift!=1


*** TRANSFORMATION OF PRODUCTS
ren h61 transfprod
label var transfprod "HH transformed agric or animal product over past 12 months"
recode transfprod 2=0

#delimit ;
label def product
	1 "corn flower"
	2 "dry cassava"
	3 "cassava flower"
	4 "sorghum flower"
	5 "banana beer"
	6 "sorghum beer"
	7 "maracuja juice"
	8 "banana juice"
	9 "dry fish"
	10 "peanut flower"
	11 "butter"
	12 "amata ikivuguru"
	13 "other cereal flower"
	14 "coal from wood";

label def waymoney
	1 "savings"
	2 "selling animals"
	3 "selling other products"
	4 "selling assets"
	5 "debt at association"
	6 "bank credit"
	7 "other";
#delimit cr

ren h62a traprod1
label var traprod1 "1st product obtained by HH"
label val traprod1 product

ren h63a soldprod1
label var soldprod1 "1st product has been sold"
recode soldprod1 2=0

ren h62b traprod2
label var traprod2 "2nd product obtained by HH"
label val traprod2 product

ren h63b soldprod2
label var soldprod2 "2nd product has been sold"
recode soldprod2 2=0
	
ren h62c traprod3
label var traprod3 "3rd product obtained by HH"
label val traprod3 product

ren h63c soldprod3
label var soldprod3 "3rd product has been sold"
recode soldprod3 2=0



*** SELF-FINANCING ABILITY
ren h71 availmoney
label var availmoney "possibility to get 1000 FRW if needed"
recode availmoney 2=0

ren h72 obtmoney
label var obtmoney "where HH can get 1000 FRW if they do not have"
label def obtmoney 1 "family" 2 "neighbor" 3 "relig assoc" 4 "mutual aid assoc" 5 "other"
label val obtmoney obtmoney

ren h73 waymoney
label var waymoney "mean to get 1000 FRW if they have the possibility to get them"
label val waymoney waymoney


*** CURRENT CONSUMPTION

label def evol 1 "increase" 2 "same" 3 "decrease"


ren h81a matches
label var matches "monthly amount spent in matches"

ren h81b evmatches
label var evmatches "evolution in matches prices"
label val evmatches evol
replace evmatches=. if evmatches==4

ren h82a soap
label var soap "monthly amount spent in soap"
replace soap=. if soap==9999

ren h82b evsoap
label var evsoap "evolution in soap prices"
label val evsoap evol
replace evsoap=. if evsoap==4

ren h83a oil
label var oil "monthly amount spent in lamp oil"

ren h83b evoil
label var evoil "evolution in oil prices"
label val evoil evol
replace evoil=. if evoil==4

ren h84a wood
label var wood "monthly amount spent in wood/coal"
replace wood=. if wood==9999

ren h84b evwood
label var evwood "evolution in wood prices"
label val evwood evol
replace evwood=. if evwood==4


ren h85a salt
label var salt "monthly amount spent in salt"

ren h85b evsalt
label var evsalt "evolution in salt prices"
label val evsalt evol
replace evsalt=. if evsalt==4


ren h86a sugar
label var sugar "monthly amount spent in sugar"
replace sugar=. if sugar==9999

ren h86b evsugar
label var evsugar "evolution in sugar prices"
label val evsugar evol
replace evsugar=. if evsugar==4


ren h87a beans
label var beans "monthly amount spent in beans"

ren h87b evbeans
label var evbeans "evolution in beans prices"
label val evbeans evol
replace evbeans=. if evbeans==4


ren h88a meat
label var meat "monthly amount spent in meat"

ren h88b evmeat
label var evmeat "evolution in meat prices"
label val evmeat evol
replace evmeat=. if evmeat==4


ren h89a fish
label var fish "monthly amount spent in fish"

ren h89b evfish
label var evfish "evolution in fish prices"
label val evfish evol
replace evfish=. if evfish==4


ren h810a rice
label var rice "monthly amount spent in rice"

ren h810b evrice
label var evrice "evolution in rice prices"
label val evrice evol
replace evrice=. if evrice==4


ren h811a beerhand
label var beerhand "monthly amount spent in hand-crafted beer"

ren h811b evbeerhand
label var evbeerhand "evolution in hand-crafted beer prices"
label val evbeerhand evol
replace evbeerhand=. if evbeerhand==4 


ren h812a beerind
label var beerind "monthly amount spent in industrial beer"

ren h812b evbeerind
label var evbeerind "evolution in industrial beer prices"
label val evbeerind evol
replace evbeerind=. if evbeerind==4 


*** FARM ANIMALS
drop goats sheep pigs rabbit poultry cows allumet savon petrole charbon /*
	*/ sel sucre haricots viande poisson riz beer_art beer_ind

ren h91 anact
label var anact "HH has raised farm animals in the past 12 months"
recode anact 2=0

ren h92a goats
label var goats "number of goats"

ren h92b sheep
label var sheep "number of sheep"

ren h92c pigs
label var pigs "number of pigs"

ren h92d rabbits
label var rabbits "number of rabbits"

ren h92e birds
label var birds "number of birds"

ren h92f cows
label var cows "number of cows"


ren h93a goatevol
label var goatevol "evolution of goat number with respect to 1 year ago"
label val goatevol surfevol

ren h93b sheepevol
label var sheepevol "evolution of sheep number with respect to 1 year ago"
label val sheepevol surfevol

ren h93c pigevol
label var pigevol "evolution of pig number with respect to 1 year ago"
label val pigevol surfevol

ren h93d rabbitevol
label var rabbitevol "evolution of rabbit number with respect to 1 year ago"
label val rabbitevol surfevol

ren h93e birdevol
label var birdevol "evolution of birds number with respect to 1 year ago"
label val birdevol surfevol

ren h93f cowevol
label var cowevol "evolution of cows number with respect to 1 year ago"
label val cowevol surfevol


ren h94a goatsd
label var goatsd "goats have been sold"
recode goatsd 2=0

ren h94b sheepsd
label var sheepsd "sheep have been sold"
recode sheepsd 2=0

ren h94c pigsd
label var pigsd "pigs have been sold"
recode pigsd 2=0

ren h94d rabbitsd
label var rabbitsd "rabbits have been sold"
recode rabbitsd 2=0

ren h94e birdsd
label var birdsd "birds have been sold"
recode birdsd 2=0

ren h94f cowsd
label var cowsd "cows have been sold"
recode cowsd 2=0


ren h95a goatcons
label var goatcons "goats have been consumed"
recode goatcons 2=0

ren h95b sheepcons
label var sheepcons "sheep have been consumed"
recode sheepcons 2=0

ren h95c pigcons
label var pigcons "pigs have been consumed"
recode pigcons 2=0

ren h95d rabbitcons
label var rabbitcons "rabbits have been consumed"
recode rabbitcons 2=0

ren h95e birdcons
label var birdcons "birds have been consumed"
recode birdcons 2=0

ren h95f cowcons
label var cowcons "cows have been consumed"
recode cowcons 2=0


ren h96 pasture
label var pasture "HH owns pasture for animals"
recode pasture 2=0

ren h97 compost
label var compost "HH produces compost"
recode compost 2=0

ren h98 compuse
label var compuse "main use of compost"
label def compuse 1 "crops" 2 "sale" 3 "other"
label val compuse compuse

ren h99 veterinary
label var veterinary "HH ever used veterinary services"
recode veterinary 2=0

ren h910 veterjudge
label var veterjudge "opinion on veterinary services"
label def veterjudge 1 "very unsatisf" 2 "unsatisf" 3 "somewhat satisf" 4 "very satisf" 5 "do not know"
label val veterjudge veterjudge

ren h911 veterno
label var veterno "why not used veterinary services"
label def veterno 1 "not needed" 2 "very far" 3 "very expens" 4 "bad reception" 5 "ineffective" /*
	*/ 6 "no real service" 7 "difficult to find" 8 "other"
label val veterno veterno

ren h912a noanimals
label var noanimals "HH does not desire to have animals"
replace noanimals=0 if anact==0 & noanimals==.

ren h912b yescow
label var yescow "HH would like to have cows"
replace yescow=0 if anact==0 & yescow==.

ren h912c yesgoat
label var yesgoat "HH would like to have goats"
replace yesgoat=0 if anact==0 & yesgoat==.

ren h912d yessheep
label var yessheep "HH would like to have sheep"
replace yessheep=0 if anact==0 & yessheep==.

ren h912e yespig
label var yespig "HH would like to have pigs"
replace yespig=0 if anact==0 & yespig==.



sort hhid
save "C:\Documents and Settings\wb200856\My Documents\Africa\rwa\data\QUIBB\sectionh.dta", replace

log close



***********************************************************************
